API Documentation
=================


Loaders
-------

The loaders are responsible for loading from a filepath, reading a file-like
object, or parsing a string.

.. automodule:: tsplib95.loaders
    :members:
    :show-inheritance:


Problems
--------

Problem classes define what fields can be present and how they are converted
to and from text.

.. automodule:: tsplib95.models
    :members:
    :show-inheritance:


Fields
------

.. automodule:: tsplib95.fields
    :members:
    :show-inheritance:


Transformers
------------

.. automodule:: tsplib95.transformers
    :members:
    :show-inheritance:


Matrices
--------

.. automodule:: tsplib95.matrix
    :members:
    :show-inheritance:


Distances
---------

.. automodule:: tsplib95.distances
    :members:
    :show-inheritance:


Biseps
------

.. automodule:: tsplib95.bisep
    :members:
    :show-inheritance:


Utilities
---------

.. automodule:: tsplib95.utils
    :members:
    :show-inheritance:


Exceptions
----------

.. automodule:: tsplib95.exceptions
    :members:
    :show-inheritance:
